# Hemoglobin

Hemoglobin is a CLI wrapper for GrammarBot so that it can be used to check your content for errors.

## Installation

```bash
python3 -m pip install hemoglobin
```

## Usage

```bash
python3 -m hemoglobin exampleApiKey ./content
```
